/******************************************************
  SCIDYNE Corporation  649 School Street  Pembroke MA 02359  USA  https://scidyne.com
  SCIDYNE_DIO24ARD.h - Library header file for SCIDYNE DIO24-ARD #100-7692
  Created by Mark Durgin, October 2, 2022   Version 1.0.0

  MIT License https://opensource.org/licenses/MIT

  Copyright 2022 SCIDYNE Corporation or its affiliates.  All Rights Reserved. 

  Permission is hereby granted, free of charge, to any person obtaining a copy of
  this software and associated documentation files (the "Software"), to deal in
  the Software without restriction, including without limitation the rights to
  use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
  the Software, and to permit persons to whom the Software is furnished to do so,
  subject to the following conditions:

  The above copyright notice and this permission notice shall be included in all
  copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
  FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
  COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
  IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
  CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

*******************************************************/

#ifndef _SCIDYNE_DIO24ARD_h_INCLUDED
#define _SCIDYNE_DIO24ARD_h_INCLUDED


//#include "Arduino.h"
#if ARDUINO >= 100
  #include "Arduino.h"
#else
  #include "WProgram.h"
#endif


#include "SPI.h"



class SCIDYNE_DIO24ARD    // The class
{
  public: // Access specifier
    void setup( uint16_t pinNumber, uint8_t portA_DDR, uint8_t portB_DDR, uint8_t portC_DDR );
    void writeDDR ( uint8_t DDR_to_Write, uint8_t DDR_value );
    uint8_t readDDR( uint8_t DDR_to_Read );
    void setBit ( uint8_t bitNumber );
    void clrBit ( uint8_t bitNumber );
    void bitSetClr ( uint8_t bitNumber, bool State );
    bool readBit ( uint8_t bitNumber );
    void portWrite( uint8_t port_to_Write, uint8_t port_Byte );
    uint8_t portRead( uint8_t port_to_Read );
    
  private:  // Access specifier
    // Declare constants
    const uint8_t CMD_WR = 0x00;			// Write Command  
    const uint8_t CMD_RD = 0x01;                        // Read Command
    enum ports { portA, portB, portC };                 // Associate portA, portB, portC to values 0, 1, 2 respectively
    static const uint8_t NUMBER_OF_PORTS = 3;           // Number of ports on a DIO24-ARD      
    const uint8_t BITS_PER_BYTE = 8;    		// Number of bits in a byte 

    // Declare Attributes (variables)
    uint16_t  selectPin;                                // Retains the designated digital I/O select pin between library calls 
    uint8_t   pseudoDDR[NUMBER_OF_PORTS];               // Retains Port Data Direction Registers
};

#endif
